==> power_reviews-8.x-1.0.tar.gz: power_reviews/src/Routing/PowerReviewsRouteSubscriber.php <==
<?php

namespace Drupal\power_reviews\Routing;

use Symfony\Component\Routing\Route;
use Symfony\Component\Routing\RouteCollection;
use Drupal\Core\Routing\RouteSubscriberBase;
use Drupal\Core\Config\ConfigFactoryInterface;

/**
 * Defines dynamic routes.
 */
class PowerReviewsRouteSubscriber extends RouteSubscriberBase {

  /**
   * The config factory.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * PowerReviewsRouteSubscriber constructor.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   Config Factory object.
   */
  public function __construct(ConfigFactoryInterface $config_factory) {
    $this->configFactory = $config_factory;
  }

  /**
   * {@inheritdoc}
   */
  public function routes() {
    $routes = [];
    $config = $this->configFactory->get('power_reviews.settings');

    // Declares a single route under the name 'power_reviews.write_review'.
    // Returns an array of Route objects.
    $routes['power_reviews.write_review'] = new Route(
      // Path to attach this route to:
      $config->get('power_reviews_write_review_link'),
      // Route defaults:
      [
        '_controller' => '\Drupal\power_reviews\Controller\PowerReviewsController::writeReview',
        '_title' => $config->get('power_reviews_write_review_page_title'),
      ],
      // Route requirements:
      [
        '_permission' => 'access content',
      ]
    );

    return $routes;
  }

  /**
   * {@inheritdoc}
   */
  protected function alterRoutes(RouteCollection $collection) {
    $config = $this->configFactory->get('power_reviews.settings');
    // Change path '/user/login' to '/login'.
    if ($route = $collection->get('power_reviews.write_review')) {
      $route->setPath($config->get('power_reviews_write_review_link'));
    }
    // Always deny access to '/user/logout'.
    // Note that the second parameter of setRequirement() is a string.
    if ($route = $collection->get('user.logout')) {
      $route->setDefault('_title', $config->get('power_reviews_write_review_page_title'));
    }
  }

}

==> power_reviews-8.x-2.0.tar.gz: power_reviews/src/Routing/PowerReviewsRouteSubscriber.php <==
<?php

namespace Drupal\power_reviews\Routing;

use Symfony\Component\Routing\Route;
use Symfony\Component\Routing\RouteCollection;
use Drupal\Core\Routing\RouteSubscriberBase;
use Drupal\Core\Config\ConfigFactoryInterface;

/**
 * Defines dynamic routes.
 */
class PowerReviewsRouteSubscriber extends RouteSubscriberBase {

  /**
   * The config factory.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * {@inheritdoc}
   */
  public function routes() {
    $routes = [];
    $config = \Drupal::configFactory()->get('power_reviews.settings');

    // Declares a single route under the name 'power_reviews.write_review'.
    // Returns an array of Route objects.
    $routes['power_reviews.write_review'] = new Route(
      // Path to attach this route to:
      $config->get('power_reviews_write_review_link'),
      // Route defaults:
      [
        '_controller' => '\Drupal\power_reviews\Controller\PowerReviewsController::writeReview',
        '_title' => $config->get('power_reviews_write_review_page_title'),
      ],
      // Route requirements:
      [
        '_permission' => 'access content',
      ]
    );

    return $routes;
  }

  /**
   * {@inheritdoc}
   */
  protected function alterRoutes(RouteCollection $collection) {
    $config = \Drupal::configFactory()->get('power_reviews.settings');
    // Change path '/user/login' to '/login'.
    if ($route = $collection->get('power_reviews.write_review')) {
      $route->setPath($config->get('power_reviews_write_review_link'));
    }
    // Always deny access to '/user/logout'.
    // Note that the second parameter of setRequirement() is a string.
    if ($route = $collection->get('user.logout')) {
      $route->setDefault('_title', $config->get('power_reviews_write_review_page_title'));
    }
  }

}
